<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
version="1.0"
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xl="http://www.w3.org/1999/xlink"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--rst

.. _table_authors.xsl:

=================
table_authors.xsl
=================

DESCRIPTION
===========

creation of a table with every author with an associated external or internal link

EVOLUTIONS
==========

$Id$

- fplod 2008-05-16T13:38:07Z aedon.locean-ipsl.upmc.fr (Darwin)

  * handling less than 8 different authors

- fplod 2008-04-29T15:45:13Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 in

- fplod 2008-04-29T08:04:57Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 out

- fplod 2007-10-17T07:48:19Z aedon.locean-ipsl.upmc.fr (Darwin)

  * improve sort (diacriticals)

- fplod 2007-05-18T14:40:38Z aedon.locean-ipsl.upmc.fr (Darwin)

  * modif gestion des id

- fplod 2007-05-16T15:01:39Z aedon.locean-ipsl.upmc.fr (Darwin)

  * correction pour homonymes partiels

- fplod 2007-04-18T13:32:33Z aedon.locean-ipsl.upmc.fr (Darwin)

  * creation

-->

<xsl:output
 method="xml"
 indent="yes"
 omit-xml-declaration="no"/>

<xsl:template name="table_authors">
<xsl:param name="linktype"/>
<!--
creation of an informatable of 8 cols max
each entry of the table is a link #SURNAME_f
-->

<xsl:variable name="nb_auth"
              select="count(///d:author[not( self::node() = following::d:author )])"/>

<xsl:variable name="nb_cols_max" select="8"/>

<xsl:variable name="nb_cols">
<xsl:choose>
 <xsl:when test="($nb_auth > $nb_cols_max)">
  <xsl:value-of select="$nb_cols_max"/>
 </xsl:when>
 <xsl:otherwise>
  <xsl:value-of select="$nb_auth"/>
 </xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:element name="informaltable">
 <xsl:attribute name="xml:id">author_ids</xsl:attribute>
 <xsl:attribute name="summary">author_ids of publications</xsl:attribute>
 <xsl:attribute name="width">80%</xsl:attribute>
 <xsl:element name="tgroup">
  <xsl:attribute name="cols"><xsl:value-of select="$nb_cols"/></xsl:attribute>
  <xsl:attribute name="align">center</xsl:attribute>
  <xsl:attribute name="colsep">1</xsl:attribute>
  <xsl:attribute name="rowsep">1</xsl:attribute>
  <xsl:element name="tbody">
   <xsl:for-each select="///d:author[not( self::node() = following::d:author )]">
    <xsl:sort order="ascending" data-type="text" select="translate(.,'abcdefghijklmnopqrstuvwxyz ', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
    <xsl:if test="position() = 1 or position() mod $nb_cols = 1">
     <xsl:text>&#xA;</xsl:text>
     <xsl:comment> dbut de row <xsl:value-of select="position()"/></xsl:comment>
      <xsl:text disable-output-escaping="yes">
      <![CDATA[
<row>
]]>
     </xsl:text>
    </xsl:if>
    <xsl:text>&#xA;</xsl:text>
    <xsl:element name="entry">
     <xsl:variable name="author_id">
<xsl:call-template name="surname_id">
 <xsl:with-param name="surname" select="d:personname/d:surname"/>
</xsl:call-template>
<xsl:text>_</xsl:text>
<xsl:call-template name="firstname_id">
 <xsl:with-param name="firstname" select="d:personname/d:firstname"/>
</xsl:call-template>
     </xsl:variable>
     <xsl:text>&#xA;</xsl:text>
     <xsl:element name="link">
      <xsl:choose>
       <xsl:when test="$linktype='internal'">
        <xsl:attribute name="xl:href"><xsl:text>#</xsl:text><xsl:value-of select="$author_id"/></xsl:attribute>
       </xsl:when>
       <xsl:when test="$linktype='external'">
        <xsl:attribute name="xl:href"><xsl:value-of select="concat($author_id,$html.ext)"/></xsl:attribute>
       </xsl:when>
       <xsl:otherwise>
        <xsl:message terminate="yes">
eee : unknown linktype = <xsl:value-of select="$linktype"/>
        </xsl:message>
       </xsl:otherwise>
      </xsl:choose>
<xsl:value-of select="normalize-space(d:personname/d:firstname)"/><xsl:text> </xsl:text><xsl:value-of select="normalize-space(d:personname/d:surname)"/>
     </xsl:element>
    </xsl:element>
    <xsl:if test="position() mod $nb_cols = 0 or position()=last()">
     <xsl:text>&#xA;</xsl:text>
     <xsl:comment> fin de row <xsl:value-of select="position()"/></xsl:comment>
     <xsl:text disable-output-escaping="yes">
     <![CDATA[
</row>
]]>
     </xsl:text>
    </xsl:if>
   </xsl:for-each>
  </xsl:element>
 </xsl:element>
</xsl:element>
</xsl:template>
</xsl:stylesheet>
